==> foundation-4.6.x-1.x-dev.tar.gz: foundation/page.tpl.php <==
<?php /* $Id$ */ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language; ?>" xml:lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?>
<?php print $styles; ?>
<script type="text/javascript"> </script>
</head>
<body class="body-<?php print $layout; ?>"<?php print $onload_attributes; ?>>

<div class="header">
  <h1>
    <?php if ($logo): ?>
    <a href="<?php print url(NULL, NULL, NULL, TRUE); ?>"><img src="<?php print $logo; ?>" alt="" class="logo" /></a>
    <?php endif; ?>

    <?php if ($site_name): ?>
    <span class="site-name"><a href="<?php print url(NULL, NULL, NULL, TRUE); ?>"><?php print $site_name; ?></a></span>
    <?php endif; ?>

    <?php if ($site_slogan): ?>
    <span class="site-slogan"><?php print $site_slogan; ?></span>
    <?php endif; ?>
  </h1>

  <?php if ($primary_links || $secondary_links): ?>
  <div class="navigation">
    <?php if ($primary_links): ?>
    <div class="navigation-primary">
      <?php print theme('links', $primary_links); ?>
    </div>
    <?php endif; ?>

    <?php if ($secondary_links): ?>
    <div class="navigation-secondary">
      <?php print theme('links', $secondary_links); ?>
    </div>
    <?php endif; ?>
  </div>
  <?php endif; ?>

  <?php if ($search_box): ?>
  <form action="<?php print url("search") ?>" method="post" class="search">
    <input class="form-text" type="text" size="15" value="" name="keys" />
    <input class="form-submit" type="submit" value="<?php print t("Search")?>" />
    <?php if (function_exists('form_token')) { print form_token(); } ?>
  </form>
  <?php endif; ?>
</div>

<div class="container">
  <?php if ($sidebar_left): ?>
  <div class="sidebar sidebar-left"><?php print $sidebar_left; ?></div>
  <?php endif; ?>

  <div class="page">
    <?php if ($breadcrumb): ?>
    <div class="breadcrumb"><?php print $breadcrumb; ?></div>
    <?php endif; ?>

    <?php if ($messages): ?>
    <?php print $messages; ?>
    <?php endif; ?>

    <?php if ($is_front && $mission): ?>
    <div class="mission"><?php print $mission; ?></div>
    <?php endif; ?>

    <?php if ($title): ?>
    <h2 class="title"><?php print $title; ?></h2>
    <?php endif; ?>

    <?php if ($help): ?>
    <div class="help"><?php print $help; ?></div>
    <?php endif; ?>

    <?php if ($tabs): ?>
    <?php print $tabs; ?>
    <?php endif; ?>

    <?php print $content; ?>
  </div>

  <?php if ($sidebar_right): ?>
  <div class="sidebar sidebar-right"><?php print $sidebar_right; ?></div>
  <?php endif; ?>

  <div style="clear:both"></div>
</div>

<div class="footer">
  <?php if ($footer_message): ?><?php print $footer_message; ?><?php endif; ?>
</div>

<?php print $closure; ?>
</body>
</html>

==> foundation-4.7.x-1.x-dev.tar.gz: foundation/page.tpl.php <==
<?php /* $Id$ */ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language; ?>" xml:lang="<?php print $language; ?>">
<head>
<title><?php print $head_title; ?></title>
<?php print $head; ?>
<?php print $styles; ?>
<script type="text/javascript"> </script>
</head>
<body class="body-<?php print $layout; ?>">

<div class="header">
  <h1>
    <?php if ($logo): ?>
    <a href="<?php print base_path(); ?>"><img src="<?php print $logo; ?>" alt="" class="logo" /></a>
    <?php endif; ?>

    <?php if ($site_name): ?>
    <span class="site-name"><a href="<?php print base_path(); ?>"><?php print $site_name; ?></a></span>
    <?php endif; ?>

    <?php if ($site_slogan): ?>
    <span class="site-slogan"><?php print $site_slogan; ?></span>
    <?php endif; ?>
  </h1>

  <?php if ($primary_links || $secondary_links): ?>
  <div class="navigation">
    <?php if ($primary_links): ?>
    <div class="navigation-primary">
      <?php print theme('links', $primary_links); ?>
    </div>
    <?php endif; ?>

    <?php if ($secondary_links): ?>
    <div class="navigation-secondary">
      <?php print theme('links', $secondary_links); ?>
    </div>
    <?php endif; ?>
  </div>
  <?php endif; ?>

  <?php if ($search_box): ?>
  <form action="<?php print url("search") ?>" method="post" class="search">
    <input class="form-text" type="text" size="15" value="" name="keys" />
    <input class="form-submit" type="submit" value="<?php print t("Search")?>" />
  </form>
  <?php endif; ?>

  <?php print $header; ?>
</div>

<div class="container">
  <?php if ($sidebar_left): ?>
  <div class="sidebar sidebar-left"><?php print $sidebar_left; ?></div>
  <?php endif; ?>

  <div class="page">
    <?php if ($breadcrumb): ?>
    <div class="breadcrumb"><?php print $breadcrumb; ?></div>
    <?php endif; ?>

    <?php if ($messages): ?>
    <?php print $messages; ?>
    <?php endif; ?>

    <?php print $contenttop; ?>

    <?php if ($is_front && $mission): ?>
    <div class="mission"><?php print $mission; ?></div>
    <?php endif; ?>

    <?php if ($title): ?>
    <h2 class="title"><?php print $title; ?></h2>
    <?php endif; ?>

    <?php if ($help): ?>
    <div class="help"><?php print $help; ?></div>
    <?php endif; ?>

    <?php if ($tabs): ?>
    <?php print $tabs; ?>
    <?php endif; ?>

    <?php print $content; ?>
  </div>

  <?php if ($sidebar_right): ?>
  <div class="sidebar sidebar-right"><?php print $sidebar_right; ?></div>
  <?php endif; ?>

  <div style="clear:both"></div>
</div>

<div class="footer">
  <?php if ($footer_message): ?><?php print $footer_message; ?><?php endif; ?>
</div>

<?php print $closure; ?>
</body>
</html>
